@@ -14,11 +14,9 @@
 
 package org.eclipse.equinox.http.servlet.tests.tb1;
 
-import java.io.IOException;
 import java.io.PrintWriter;
 
 import javax.servlet.ServletContext;
-import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 
 import org.eclipse.equinox.http.servlet.tests.tb.AbstractTestServlet;
@@ -30,7 +28,7 @@ public class TestServlet4 extends AbstractTestServlet {
 	private static final long serialVersionUID = 1L;
 
 	@Override
-	protected void handleDoGet(HttpServletRequest request, PrintWriter writer) throws ServletException, IOException {
+	protected void handleDoGet(HttpServletRequest request, PrintWriter writer) {
 		ServletContext servletContext = getServletContext();
 		writer.print(servletContext.getContextPath());
 	}
