@@ -56,14 +56,14 @@ public class TestServlet9 extends AbstractTestServlet {
 	}
 
 	@Override
-	protected void handleDoGet(HttpServletRequest request, PrintWriter writer) throws ServletException, IOException {
+	protected void handleDoGet(HttpServletRequest request, PrintWriter writer) {
 		//
 	}
 
 	class DispatchTo extends AbstractTestServlet {
 		private static final long serialVersionUID = 1L;
 		@Override
-		protected void handleDoGet(HttpServletRequest request, PrintWriter writer) throws ServletException, IOException {
+		protected void handleDoGet(HttpServletRequest request, PrintWriter writer) {
 			writer.print(TestServlet9.this.getProperties().get(Constants.SERVICE_DESCRIPTION));
 		}
 		
