@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2011, 2019 IBM Corporation and others.
+ * Copyright (c) 2011, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -11,11 +11,13 @@
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *     Raymond Augé <raymond.auge@liferay.com> - Bug 436698
+ *     Dirk Fauth <dirk.fauth@googlemail.com> - Bug 567831
  *******************************************************************************/
 package org.eclipse.equinox.http.servlet.tests.util;
 
 import static org.junit.Assert.assertEquals;
 
+import java.io.DataOutputStream;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.IOException;
@@ -26,8 +28,10 @@ import java.io.PrintWriter;
 import java.net.HttpURLConnection;
 import java.net.URL;
 import java.net.URLConnection;
+import java.nio.charset.StandardCharsets;
 import java.security.KeyStore;
 import java.util.Arrays;
+import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
@@ -49,25 +53,35 @@ public class ServletRequestAdvisor extends Object {
 	private final String port;
 	private final String ksPath;
 	private final String ksPassword;
+	private final int timeout;
 
 	public ServletRequestAdvisor(String port, String contextPath) {
-		this(port, contextPath, null, null);
+		this(port, contextPath, null, null, 150);
 	}
-	
+
+	public ServletRequestAdvisor(String port, String contextPath, int timeout) {
+		this(port, contextPath, null, null, timeout);
+	}
+
 	public ServletRequestAdvisor(String port, String contextPath, String ksPath, String ksPassword) {
+		this(port, contextPath, ksPath, ksPassword, 150);
+	}
+
+	public ServletRequestAdvisor(String port, String contextPath, String ksPath, String ksPassword, int timeout) {
 		super();
 		if (port == null)
-		 {
+		{
 			throw new IllegalArgumentException("port must not be null"); //$NON-NLS-1$
 		}
 		this.port = port;
 		this.contextPath = contextPath;
 		this.ksPath = ksPath;
 		this.ksPassword = ksPassword;
+		this.timeout = timeout * 100000;
 	}
 
 	private String createUrlSpec(String value, boolean isHttps) {
-		StringBuffer buffer = new StringBuffer(100);
+		StringBuilder buffer = new StringBuilder(100);
 		String protocol = "http://"; //$NON-NLS-1$
 		if (isHttps) {
 			protocol = "https://";
@@ -83,16 +97,16 @@ public class ServletRequestAdvisor extends Object {
 			buffer.append(value);
 		}
 		return buffer.toString();
-		
+
 	}
 
 	private String createUrlSpec(String value) {
 		return createUrlSpec(value, false);
 	}
-	
+
 	private String drain(InputStream stream) throws IOException {
 		byte[] bytes = new byte[100];
-		StringBuffer buffer = new StringBuffer(500);
+		StringBuilder buffer = new StringBuilder(500);
 		int length;
 		while ((length = stream.read(bytes)) != -1) {
 			String chunk = new String(bytes, 0, length);
@@ -114,8 +128,8 @@ public class ServletRequestAdvisor extends Object {
 		HttpURLConnection connection = (HttpURLConnection)url.openConnection();
 
 		connection.setInstanceFollowRedirects(false);
-		connection.setConnectTimeout(150 * 100000);
-		connection.setReadTimeout(150 * 100000);
+		connection.setConnectTimeout(timeout);
+		connection.setReadTimeout(timeout);
 		connection.connect();
 
 		InputStream stream = connection.getInputStream();
@@ -125,30 +139,30 @@ public class ServletRequestAdvisor extends Object {
 			stream.close();
 		}
 	}
-	
+
 	public String requestHttps(String value) throws Exception {
 		String spec = createUrlSpec(value, true);
 		log("Requesting " + spec); //$NON-NLS-1$
 		URL url = new URL(spec);
 		SSLContext sslContext = SSLContext.getInstance("SSL");
 		initializeSSLContext(sslContext, ksPath, ksPassword);
-		
+
 		HttpsURLConnection httpsConn = (HttpsURLConnection)url.openConnection();
 		httpsConn.setSSLSocketFactory(sslContext.getSocketFactory());
 		httpsConn.setRequestMethod("GET");
 		httpsConn.setDoOutput(false);
 		httpsConn.setDoInput(true);
-		httpsConn.setConnectTimeout(150 * 1000);
-		httpsConn.setReadTimeout(150 * 1000);
+		httpsConn.setConnectTimeout(timeout);
+		httpsConn.setReadTimeout(timeout);
 		httpsConn.connect();
-		
+
 		assertEquals("Request to the url " + spec + " was not successful", 200 , httpsConn.getResponseCode());
 		InputStream stream = httpsConn.getInputStream();
 		try {
 			return drain(stream);
 		} finally {
 			stream.close();
-		}	
+		}
 	}
 
 	private void initializeSSLContext(SSLContext sslContext, String ksPath, String ksPassword) throws Exception {
@@ -162,15 +176,15 @@ public class ServletRequestAdvisor extends Object {
 				keyStore.load(ksStream, ksPassword.toCharArray());
 				kmFactory.init(keyStore, ksPassword.toCharArray());
 				keyManagers = kmFactory.getKeyManagers();
-			}          
+			}
 		}
-		
+
 		TrustManager[] trustManagers = getTrustManager();
-		
-		sslContext.init(keyManagers, trustManagers, null);  
-		
+
+		sslContext.init(keyManagers, trustManagers, null);
+
 	}
-	
+
 	private TrustManager[] getTrustManager() {
 		TrustManager[] trustAllCerts = new TrustManager[] { new X509TrustManager() {
 			@Override
@@ -180,11 +194,11 @@ public class ServletRequestAdvisor extends Object {
 
 			@Override
 			public void checkClientTrusted(
-										   java.security.cert.X509Certificate[] certs, String authType) {}
+										java.security.cert.X509Certificate[] certs, String authType) {}
 
 			@Override
 			public void checkServerTrusted(
-										   java.security.cert.X509Certificate[] certs, String authType) {}
+										java.security.cert.X509Certificate[] certs, String authType) {}
 		} };
 
 		return trustAllCerts;
@@ -197,8 +211,8 @@ public class ServletRequestAdvisor extends Object {
 		HttpURLConnection connection = (HttpURLConnection)url.openConnection();
 
 		connection.setInstanceFollowRedirects(false);
-		connection.setConnectTimeout(150 * 1000);
-		connection.setReadTimeout(150 * 1000);
+		connection.setConnectTimeout(timeout);
+		connection.setReadTimeout(timeout);
 
 		if (headers != null) {
 			for(Map.Entry<String, List<String>> entry : headers.entrySet()) {
@@ -210,7 +224,7 @@ public class ServletRequestAdvisor extends Object {
 
 		int responseCode = connection.getResponseCode();
 
-		Map<String, List<String>> map = new HashMap<String, List<String>>(connection.getHeaderFields());
+		Map<String, List<String>> map = new HashMap<>(connection.getHeaderFields());
 		map.put("responseCode", Collections.singletonList(String.valueOf(responseCode)));
 
 		InputStream stream;
@@ -223,11 +237,14 @@ public class ServletRequestAdvisor extends Object {
 		}
 
 		try {
-			map.put("responseBody", Arrays.asList(drain(stream)));
-			return map;
+			String drainedStream = drain(stream);
+			map.put("responseBody", Arrays.asList(drainedStream));
+		} catch (IOException e){
+			map.put("responseBody", Arrays.asList(e.getMessage()));
 		} finally {
 			stream.close();
 		}
+		return map;
 	}
 
 	public Map<String, List<String>> eventSource(String value, Map<String, List<String>> headers, final EventHandler handler) throws IOException {
@@ -240,8 +257,8 @@ public class ServletRequestAdvisor extends Object {
 		connection.setDoOutput(true);
 		//connection.setRequestProperty("Connection", "Close");
 		connection.setInstanceFollowRedirects(false);
-		connection.setConnectTimeout(150 * 1000);
-		connection.setReadTimeout(150 * 1000);
+		connection.setConnectTimeout(timeout);
+		connection.setReadTimeout(timeout);
 
 		if (headers != null) {
 			for(Map.Entry<String, List<String>> entry : headers.entrySet()) {
@@ -253,7 +270,7 @@ public class ServletRequestAdvisor extends Object {
 
 		int responseCode = connection.getResponseCode();
 
-		Map<String, List<String>> map = new HashMap<String, List<String>>(connection.getHeaderFields());
+		Map<String, List<String>> map = new HashMap<>(connection.getHeaderFields());
 		map.put("responseCode", Collections.singletonList(String.valueOf(responseCode)));
 
 		InputStream stream;
@@ -271,27 +288,43 @@ public class ServletRequestAdvisor extends Object {
 	}
 
 	public Map<String, List<String>> upload(String value, Map<String, List<Object>> headers) throws IOException {
+		return upload(value, headers, null);
+	}
+	
+	public Map<String, List<String>> upload(String value, Map<String, List<Object>> headers, Map<String, Object> formFields) throws IOException {
 		String spec = createUrlSpec(value);
 		log("Requesting " + spec); //$NON-NLS-1$
 		URL url = new URL(spec);
 		HttpURLConnection connection = (HttpURLConnection)url.openConnection();
 
 		connection.setInstanceFollowRedirects(false);
-		connection.setConnectTimeout(150 * 1000);
-		connection.setReadTimeout(150 * 1000);
+		connection.setConnectTimeout(timeout);
+		connection.setReadTimeout(timeout);
+		connection.setUseCaches(false);
 
 		if (headers != null) {
 			if (headers.containsKey("method")) {
-				connection.setRequestMethod((String)headers.remove("method").get(0));
+				String method = (String)headers.remove("method").get(0);
+				connection.setRequestMethod(method);
 			}
 
 			for(Map.Entry<String, List<Object>> entry : headers.entrySet()) {
 				for(Object entryValue : entry.getValue()) {
 					if (entryValue instanceof String) {
-						connection.setRequestProperty(entry.getKey(), (String)entryValue);
+						if (entry.getKey().equals("x-www-form-urlencoded")) {
+							postFormURLEncoded(connection, (String)entryValue);
+						}
+						else {
+							String property = connection.getRequestProperty(entry.getKey());
+							if (property == null) {
+								connection.setRequestProperty(entry.getKey(), (String)entryValue);
+							} else {
+								connection.setRequestProperty(entry.getKey(), property + "," + entryValue);
+							}
+						}
 					}
 					else if (entryValue instanceof URL) {
-						uploadFileConnection(connection, entry.getKey(), (URL)entryValue);
+						uploadFileConnection(connection, entry.getKey(), (URL)entryValue, formFields);
 					}
 					else {
 						throw new IllegalArgumentException("only supports strings and files");
@@ -302,7 +335,7 @@ public class ServletRequestAdvisor extends Object {
 
 		int responseCode = connection.getResponseCode();
 
-		Map<String, List<String>> map = new HashMap<String, List<String>>(connection.getHeaderFields());
+		Map<String, List<String>> map = new HashMap<>(connection.getHeaderFields());
 		map.put("responseCode", Collections.singletonList(String.valueOf(responseCode)));
 
 		InputStream stream;
@@ -322,7 +355,23 @@ public class ServletRequestAdvisor extends Object {
 		}
 	}
 
-	private void uploadFileConnection(HttpURLConnection connection, String param, URL file)
+	private void postFormURLEncoded(HttpURLConnection connection, String param)
+		throws IOException {
+
+		byte[] bytes = param.getBytes(StandardCharsets.UTF_8);
+
+		connection.setDoOutput(true);
+		connection.setRequestProperty("Content-Type", "application/x-www-form-urlencoded");
+		//connection.setRequestProperty("Content-Length", Integer.toString(bytes.length));
+
+		try(DataOutputStream wr = new DataOutputStream(connection.getOutputStream())) {
+			wr.write(bytes);
+			wr.flush();
+		}
+	}
+
+	@SuppressWarnings({ "unchecked", "rawtypes" })
+	private void uploadFileConnection(HttpURLConnection connection, String param, URL file, Map<String, Object> formFields)
 		throws IOException {
 
 		String fileName = file.getPath();
@@ -333,14 +382,41 @@ public class ServletRequestAdvisor extends Object {
 		String CRLF = "\r\n";
 		connection.setRequestProperty("Content-Type", "multipart/form-data; boundary=" + boundary);
 
-		InputStream input = null;
-		OutputStream output = null;
-		PrintWriter writer = null;
-
-		try {
-			output = connection.getOutputStream();
-			writer = new PrintWriter(new OutputStreamWriter(output, "UTF-8"), true);
+		try (InputStream input = file.openStream();
+				OutputStream output = connection.getOutputStream();
+				PrintWriter writer = new PrintWriter(new OutputStreamWriter(output, StandardCharsets.UTF_8), true);) {
 
+			// add optional parameter
+			if (formFields != null) {
+				formFields.entrySet().forEach(entry -> {
+					if (entry.getValue() instanceof Collection) {
+						((Collection)entry.getValue()).forEach(value -> {
+							writer.append("--" + boundary);
+							writer.append(CRLF);
+							writer.append("Content-Disposition: form-data; name=\"" + entry.getKey() + "\"");
+							writer.append(CRLF);
+							writer.append("Content-Type: text/plain; charset=UTF-8");
+							writer.append(CRLF);
+							writer.append(CRLF);
+							writer.append((String) value);
+							writer.append(CRLF);
+							writer.flush();
+						});
+					} else {
+						writer.append("--" + boundary);
+						writer.append(CRLF);
+						writer.append("Content-Disposition: form-data; name=\"" + entry.getKey() + "\"");
+						writer.append(CRLF);
+						writer.append("Content-Type: text/plain; charset=UTF-8");
+						writer.append(CRLF);
+						writer.append(CRLF);
+						writer.append((String) entry.getValue());
+						writer.append(CRLF);
+						writer.flush();
+					}
+				});
+			}
+			
 			writer.append("--" + boundary);
 			writer.append(CRLF);
 			writer.append("Content-Disposition: form-data; name=\"");
@@ -361,7 +437,6 @@ public class ServletRequestAdvisor extends Object {
 			writer.flush();
 
 			byte[] buf = new byte[64];
-			input = file.openStream();
 			int c = 0;
 			while ((c = input.read(buf, 0, buf.length)) > 0) {
 				output.write(buf, 0, c);
@@ -377,17 +452,6 @@ public class ServletRequestAdvisor extends Object {
 			writer.append(CRLF);
 			writer.flush();
 		}
-		finally {
-			if (input != null) {
-				input.close();
-			}
-			if (output != null) {
-				output.close();
-			}
-			if (writer != null) {
-				writer.close();
-			}
-		}
 	}
 
 }
