@@ -14,6 +14,7 @@
 package org.eclipse.core.internal.registry;
 
 import java.io.*;
+import java.nio.charset.StandardCharsets;
 import java.util.*;
 import java.util.Map.Entry;
 import org.eclipse.core.runtime.*;
@@ -243,8 +244,8 @@ public class TableWriter {
 		Collection<?> entries = contributors.values();
 		outputContributors.writeInt(entries.size());
 
-		for (Iterator<?> i = entries.iterator(); i.hasNext();) {
-			RegistryContributor contributor = (RegistryContributor) i.next();
+		for (Object entry : entries) {
+			RegistryContributor contributor = (RegistryContributor) entry;
 			writeStringOrNull(contributor.getActualId(), outputContributors);
 			writeStringOrNull(contributor.getActualName(), outputContributors);
 			writeStringOrNull(contributor.getId(), outputContributors);
@@ -290,8 +291,8 @@ public class TableWriter {
 			return;
 		}
 		out.writeInt(array.length);
-		for (int i = 0; i < array.length; i++) {
-			out.writeInt(array[i]);
+		for (int element : array) {
+			out.writeInt(element);
 		}
 	}
 
@@ -423,7 +424,7 @@ public class TableWriter {
 		if (string == null)
 			out.writeByte(TableReader.NULL);
 		else {
-			byte[] data = string.getBytes(TableReader.UTF_8);
+			byte[] data = string.getBytes(StandardCharsets.UTF_8);
 			if (data.length > 65535) {
 				out.writeByte(TableReader.LOBJECT);
 				out.writeInt(data.length);
